# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: huawei-devm.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='huawei-devm.proto',
  package='huawei_devm',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x11huawei-devm.proto\x12\x0bhuawei_devm\"\xc6\n\n\x04\x44\x65vm\x12,\n\x08\x63puInfos\x18\x05 \x01(\x0b\x32\x1a.huawei_devm.Devm.CpuInfos\x12\x38\n\x0e\x65thPortStaStss\x18\x07 \x01(\x0b\x32 .huawei_devm.Devm.EthPortStaStss\x12\x32\n\x0bmemoryInfos\x18\x0f \x01(\x0b\x32\x1d.huawei_devm.Devm.MemoryInfos\x12&\n\x05ports\x18\x14 \x01(\x0b\x32\x17.huawei_devm.Devm.Ports\x1a\xcd\x01\n\x08\x43puInfos\x12\x33\n\x07\x63puInfo\x18\x01 \x03(\x0b\x32\".huawei_devm.Devm.CpuInfos.CpuInfo\x1a\x8b\x01\n\x07\x43puInfo\x12\x10\n\x08\x65ntIndex\x18\x01 \x01(\r\x12\x10\n\x08interval\x18\x02 \x01(\r\x12\x17\n\x0fovloadThreshold\x18\x03 \x01(\r\x12\x10\n\x08position\x18\x04 \x01(\t\x12\x16\n\x0esystemCpuUsage\x18\x05 \x01(\r\x12\x19\n\x11unovloadThreshold\x18\x06 \x01(\r\x1a\xca\x01\n\x0e\x45thPortStaStss\x12\x45\n\rethPortStaSts\x18\x01 \x03(\x0b\x32..huawei_devm.Devm.EthPortStaStss.EthPortStaSts\x1aq\n\rEthPortStaSts\x12\x0e\n\x06ifName\x18\x01 \x01(\r\x12\x13\n\x0breceiveByte\x18\x02 \x01(\x04\x12\x15\n\rreceivePacket\x18\x03 \x01(\x04\x12\x10\n\x08sendByte\x18\x04 \x01(\x04\x12\x12\n\nsendPacket\x18\x05 \x01(\x04\x1a\xcd\x03\n\x0bMemoryInfos\x12<\n\nmemoryInfo\x18\x01 \x03(\x0b\x32(.huawei_devm.Devm.MemoryInfos.MemoryInfo\x1a\xff\x02\n\nMemoryInfo\x12\x14\n\x0c\x64oMemoryFree\x18\x01 \x01(\r\x12\x15\n\rdoMemoryTotal\x18\x02 \x01(\r\x12\x15\n\rdoMemoryUsage\x18\x03 \x01(\r\x12\x13\n\x0b\x64oMemoryUse\x18\x04 \x01(\r\x12\x10\n\x08\x65ntIndex\x18\x05 \x01(\r\x12\x14\n\x0cosMemoryFree\x18\x06 \x01(\r\x12\x15\n\rosMemoryTotal\x18\x07 \x01(\r\x12\x15\n\rosMemoryUsage\x18\x08 \x01(\r\x12\x13\n\x0bosMemoryUse\x18\t \x01(\r\x12\x17\n\x0fovloadThreshold\x18\n \x01(\r\x12\x10\n\x08position\x18\x0b \x01(\t\x12\x18\n\x10simpleMemoryFree\x18\x0c \x01(\r\x12\x19\n\x11simpleMemoryTotal\x18\r \x01(\r\x12\x19\n\x11simpleMemoryUsage\x18\x0e \x01(\r\x12\x17\n\x0fsimpleMemoryUse\x18\x0f \x01(\r\x12\x19\n\x11unovloadThreshold\x18\x10 \x01(\r\x1a\x8c\x02\n\x05Ports\x12*\n\x04port\x18\x01 \x03(\x0b\x32\x1c.huawei_devm.Devm.Ports.Port\x1a\xd6\x01\n\x04Port\x12=\n\x0bopticalInfo\x18\x08 \x01(\x0b\x32(.huawei_devm.Devm.Ports.Port.OpticalInfo\x1a\x8e\x01\n\x0bOpticalInfo\x12\x13\n\x0b\x62iasCurrent\x18\x01 \x01(\t\x12\x10\n\x08manuDate\x18\x02 \x01(\t\x12\x10\n\x08position\x18\x0f \x01(\t\x12\x0f\n\x07rxPower\x18\x10 \x01(\t\x12\x13\n\x0btemperature\x18\x11 \x01(\t\x12\x0f\n\x07txPower\x18\x14 \x01(\t\x12\x0f\n\x07voltage\x18\x17 \x01(\tb\x06proto3')
)




_DEVM_CPUINFOS_CPUINFO = _descriptor.Descriptor(
  name='CpuInfo',
  full_name='huawei_devm.Devm.CpuInfos.CpuInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='entIndex', full_name='huawei_devm.Devm.CpuInfos.CpuInfo.entIndex', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interval', full_name='huawei_devm.Devm.CpuInfos.CpuInfo.interval', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ovloadThreshold', full_name='huawei_devm.Devm.CpuInfos.CpuInfo.ovloadThreshold', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position', full_name='huawei_devm.Devm.CpuInfos.CpuInfo.position', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='systemCpuUsage', full_name='huawei_devm.Devm.CpuInfos.CpuInfo.systemCpuUsage', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unovloadThreshold', full_name='huawei_devm.Devm.CpuInfos.CpuInfo.unovloadThreshold', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=306,
  serialized_end=445,
)

_DEVM_CPUINFOS = _descriptor.Descriptor(
  name='CpuInfos',
  full_name='huawei_devm.Devm.CpuInfos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpuInfo', full_name='huawei_devm.Devm.CpuInfos.cpuInfo', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEVM_CPUINFOS_CPUINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=445,
)

_DEVM_ETHPORTSTASTSS_ETHPORTSTASTS = _descriptor.Descriptor(
  name='EthPortStaSts',
  full_name='huawei_devm.Devm.EthPortStaStss.EthPortStaSts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ifName', full_name='huawei_devm.Devm.EthPortStaStss.EthPortStaSts.ifName', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receiveByte', full_name='huawei_devm.Devm.EthPortStaStss.EthPortStaSts.receiveByte', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='receivePacket', full_name='huawei_devm.Devm.EthPortStaStss.EthPortStaSts.receivePacket', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sendByte', full_name='huawei_devm.Devm.EthPortStaStss.EthPortStaSts.sendByte', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sendPacket', full_name='huawei_devm.Devm.EthPortStaStss.EthPortStaSts.sendPacket', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=650,
)

_DEVM_ETHPORTSTASTSS = _descriptor.Descriptor(
  name='EthPortStaStss',
  full_name='huawei_devm.Devm.EthPortStaStss',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ethPortStaSts', full_name='huawei_devm.Devm.EthPortStaStss.ethPortStaSts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEVM_ETHPORTSTASTSS_ETHPORTSTASTS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=650,
)

_DEVM_MEMORYINFOS_MEMORYINFO = _descriptor.Descriptor(
  name='MemoryInfo',
  full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='doMemoryFree', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.doMemoryFree', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doMemoryTotal', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.doMemoryTotal', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doMemoryUsage', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.doMemoryUsage', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doMemoryUse', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.doMemoryUse', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entIndex', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.entIndex', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='osMemoryFree', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.osMemoryFree', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='osMemoryTotal', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.osMemoryTotal', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='osMemoryUsage', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.osMemoryUsage', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='osMemoryUse', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.osMemoryUse', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ovloadThreshold', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.ovloadThreshold', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.position', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='simpleMemoryFree', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.simpleMemoryFree', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='simpleMemoryTotal', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.simpleMemoryTotal', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='simpleMemoryUsage', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.simpleMemoryUsage', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='simpleMemoryUse', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.simpleMemoryUse', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unovloadThreshold', full_name='huawei_devm.Devm.MemoryInfos.MemoryInfo.unovloadThreshold', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=1114,
)

_DEVM_MEMORYINFOS = _descriptor.Descriptor(
  name='MemoryInfos',
  full_name='huawei_devm.Devm.MemoryInfos',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='memoryInfo', full_name='huawei_devm.Devm.MemoryInfos.memoryInfo', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEVM_MEMORYINFOS_MEMORYINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=653,
  serialized_end=1114,
)

_DEVM_PORTS_PORT_OPTICALINFO = _descriptor.Descriptor(
  name='OpticalInfo',
  full_name='huawei_devm.Devm.Ports.Port.OpticalInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='biasCurrent', full_name='huawei_devm.Devm.Ports.Port.OpticalInfo.biasCurrent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='manuDate', full_name='huawei_devm.Devm.Ports.Port.OpticalInfo.manuDate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='position', full_name='huawei_devm.Devm.Ports.Port.OpticalInfo.position', index=2,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rxPower', full_name='huawei_devm.Devm.Ports.Port.OpticalInfo.rxPower', index=3,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='huawei_devm.Devm.Ports.Port.OpticalInfo.temperature', index=4,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='txPower', full_name='huawei_devm.Devm.Ports.Port.OpticalInfo.txPower', index=5,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='voltage', full_name='huawei_devm.Devm.Ports.Port.OpticalInfo.voltage', index=6,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1243,
  serialized_end=1385,
)

_DEVM_PORTS_PORT = _descriptor.Descriptor(
  name='Port',
  full_name='huawei_devm.Devm.Ports.Port',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='opticalInfo', full_name='huawei_devm.Devm.Ports.Port.opticalInfo', index=0,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEVM_PORTS_PORT_OPTICALINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1171,
  serialized_end=1385,
)

_DEVM_PORTS = _descriptor.Descriptor(
  name='Ports',
  full_name='huawei_devm.Devm.Ports',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='huawei_devm.Devm.Ports.port', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEVM_PORTS_PORT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1117,
  serialized_end=1385,
)

_DEVM = _descriptor.Descriptor(
  name='Devm',
  full_name='huawei_devm.Devm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cpuInfos', full_name='huawei_devm.Devm.cpuInfos', index=0,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ethPortStaStss', full_name='huawei_devm.Devm.ethPortStaStss', index=1,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memoryInfos', full_name='huawei_devm.Devm.memoryInfos', index=2,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ports', full_name='huawei_devm.Devm.ports', index=3,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DEVM_CPUINFOS, _DEVM_ETHPORTSTASTSS, _DEVM_MEMORYINFOS, _DEVM_PORTS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=1385,
)

_DEVM_CPUINFOS_CPUINFO.containing_type = _DEVM_CPUINFOS
_DEVM_CPUINFOS.fields_by_name['cpuInfo'].message_type = _DEVM_CPUINFOS_CPUINFO
_DEVM_CPUINFOS.containing_type = _DEVM
_DEVM_ETHPORTSTASTSS_ETHPORTSTASTS.containing_type = _DEVM_ETHPORTSTASTSS
_DEVM_ETHPORTSTASTSS.fields_by_name['ethPortStaSts'].message_type = _DEVM_ETHPORTSTASTSS_ETHPORTSTASTS
_DEVM_ETHPORTSTASTSS.containing_type = _DEVM
_DEVM_MEMORYINFOS_MEMORYINFO.containing_type = _DEVM_MEMORYINFOS
_DEVM_MEMORYINFOS.fields_by_name['memoryInfo'].message_type = _DEVM_MEMORYINFOS_MEMORYINFO
_DEVM_MEMORYINFOS.containing_type = _DEVM
_DEVM_PORTS_PORT_OPTICALINFO.containing_type = _DEVM_PORTS_PORT
_DEVM_PORTS_PORT.fields_by_name['opticalInfo'].message_type = _DEVM_PORTS_PORT_OPTICALINFO
_DEVM_PORTS_PORT.containing_type = _DEVM_PORTS
_DEVM_PORTS.fields_by_name['port'].message_type = _DEVM_PORTS_PORT
_DEVM_PORTS.containing_type = _DEVM
_DEVM.fields_by_name['cpuInfos'].message_type = _DEVM_CPUINFOS
_DEVM.fields_by_name['ethPortStaStss'].message_type = _DEVM_ETHPORTSTASTSS
_DEVM.fields_by_name['memoryInfos'].message_type = _DEVM_MEMORYINFOS
_DEVM.fields_by_name['ports'].message_type = _DEVM_PORTS
DESCRIPTOR.message_types_by_name['Devm'] = _DEVM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Devm = _reflection.GeneratedProtocolMessageType('Devm', (_message.Message,), {

  'CpuInfos' : _reflection.GeneratedProtocolMessageType('CpuInfos', (_message.Message,), {

    'CpuInfo' : _reflection.GeneratedProtocolMessageType('CpuInfo', (_message.Message,), {
      'DESCRIPTOR' : _DEVM_CPUINFOS_CPUINFO,
      '__module__' : 'huawei_devm_pb2'
      # @@protoc_insertion_point(class_scope:huawei_devm.Devm.CpuInfos.CpuInfo)
      })
    ,
    'DESCRIPTOR' : _DEVM_CPUINFOS,
    '__module__' : 'huawei_devm_pb2'
    # @@protoc_insertion_point(class_scope:huawei_devm.Devm.CpuInfos)
    })
  ,

  'EthPortStaStss' : _reflection.GeneratedProtocolMessageType('EthPortStaStss', (_message.Message,), {

    'EthPortStaSts' : _reflection.GeneratedProtocolMessageType('EthPortStaSts', (_message.Message,), {
      'DESCRIPTOR' : _DEVM_ETHPORTSTASTSS_ETHPORTSTASTS,
      '__module__' : 'huawei_devm_pb2'
      # @@protoc_insertion_point(class_scope:huawei_devm.Devm.EthPortStaStss.EthPortStaSts)
      })
    ,
    'DESCRIPTOR' : _DEVM_ETHPORTSTASTSS,
    '__module__' : 'huawei_devm_pb2'
    # @@protoc_insertion_point(class_scope:huawei_devm.Devm.EthPortStaStss)
    })
  ,

  'MemoryInfos' : _reflection.GeneratedProtocolMessageType('MemoryInfos', (_message.Message,), {

    'MemoryInfo' : _reflection.GeneratedProtocolMessageType('MemoryInfo', (_message.Message,), {
      'DESCRIPTOR' : _DEVM_MEMORYINFOS_MEMORYINFO,
      '__module__' : 'huawei_devm_pb2'
      # @@protoc_insertion_point(class_scope:huawei_devm.Devm.MemoryInfos.MemoryInfo)
      })
    ,
    'DESCRIPTOR' : _DEVM_MEMORYINFOS,
    '__module__' : 'huawei_devm_pb2'
    # @@protoc_insertion_point(class_scope:huawei_devm.Devm.MemoryInfos)
    })
  ,

  'Ports' : _reflection.GeneratedProtocolMessageType('Ports', (_message.Message,), {

    'Port' : _reflection.GeneratedProtocolMessageType('Port', (_message.Message,), {

      'OpticalInfo' : _reflection.GeneratedProtocolMessageType('OpticalInfo', (_message.Message,), {
        'DESCRIPTOR' : _DEVM_PORTS_PORT_OPTICALINFO,
        '__module__' : 'huawei_devm_pb2'
        # @@protoc_insertion_point(class_scope:huawei_devm.Devm.Ports.Port.OpticalInfo)
        })
      ,
      'DESCRIPTOR' : _DEVM_PORTS_PORT,
      '__module__' : 'huawei_devm_pb2'
      # @@protoc_insertion_point(class_scope:huawei_devm.Devm.Ports.Port)
      })
    ,
    'DESCRIPTOR' : _DEVM_PORTS,
    '__module__' : 'huawei_devm_pb2'
    # @@protoc_insertion_point(class_scope:huawei_devm.Devm.Ports)
    })
  ,
  'DESCRIPTOR' : _DEVM,
  '__module__' : 'huawei_devm_pb2'
  # @@protoc_insertion_point(class_scope:huawei_devm.Devm)
  })
_sym_db.RegisterMessage(Devm)
_sym_db.RegisterMessage(Devm.CpuInfos)
_sym_db.RegisterMessage(Devm.CpuInfos.CpuInfo)
_sym_db.RegisterMessage(Devm.EthPortStaStss)
_sym_db.RegisterMessage(Devm.EthPortStaStss.EthPortStaSts)
_sym_db.RegisterMessage(Devm.MemoryInfos)
_sym_db.RegisterMessage(Devm.MemoryInfos.MemoryInfo)
_sym_db.RegisterMessage(Devm.Ports)
_sym_db.RegisterMessage(Devm.Ports.Port)
_sym_db.RegisterMessage(Devm.Ports.Port.OpticalInfo)


# @@protoc_insertion_point(module_scope)



#
#   pmacct (Promiscuous mode IP Accounting package)
#   pmacct is Copyright (C) 2003-2020 by Paolo Lucente
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
#   pmgrpcd and its components are Copyright (C) 2018-2020 by:
#
#   Matthias Arnold <matthias.arnold@swisscom.com>
#   Raphaël P. Barazzutti <raphael@barazzutti.net>
#   Juan Camilo Cardona <jccardona82@gmail.com>
#   Thomas Graf <thomas.graf@swisscom.com>
#   Paolo Lucente <paolo@pmacct.net>
#
import logging
from pathlib import Path

SCRIPTVERSION = "3.2"

class FileNotFound(Exception):
    pass


PMGRPCDLOG = logging.getLogger("PMGRPCDLOG")
OPTIONS = None
MISSGPBLIB = {}
SERIALIZELOG = None


def init_pmgrpcdlog():
    global PMGRPCDLOG, OPTIONS
    PMGRPCDLOG.setLevel(logging.DEBUG)
    grformatter = logging.Formatter(
        "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
    )

    # create file handler which logs even debug messages
    grfh = logging.FileHandler(OPTIONS.PMGRPCDLOGfile)
    if OPTIONS.debug:
        grfh.setLevel(logging.DEBUG)
    else:
        grfh.setLevel(logging.INFO)

    grfh.setFormatter(grformatter)
    PMGRPCDLOG.addHandler(grfh)

    if OPTIONS.console:
        # create console handler with a higher log level
        grch = logging.StreamHandler()
        if OPTIONS.debug:
            grch.setLevel(logging.DEBUG)
        else:
            grch.setLevel(logging.INFO)

        grch.setFormatter(grformatter)
        PMGRPCDLOG.addHandler(grch)


def init_serializelog():
    global SERIALIZELOG
    SERIALIZELOG = logging.getLogger("SERIALIZELOG")
    SERIALIZELOG.setLevel(logging.DEBUG)
    seformatter = logging.Formatter(
        "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
    )

    # create file handler which logs even debug messages
    sefh = logging.FileHandler(OPTIONS.serializelogfile)
    if OPTIONS.debug:
        sefh.setLevel(logging.DEBUG)
    else:
        sefh.setLevel(logging.INFO)

    sefh.setFormatter(seformatter)
    SERIALIZELOG.addHandler(sefh)

    if OPTIONS.console:
        # create console handler with a higher log level
        sech = logging.StreamHandler()
        if OPTIONS.debug:
            sech.setLevel(logging.DEBUG)
        else:
            sech.setLevel(logging.INFO)

        sech.setFormatter(seformatter)
        SERIALIZELOG.addHandler(sech)


def signalhandler(signum, frame):
    global MISSGPBLIB
    # pkill -USR1 -e -f "python.*pmgrpc"
    if signum == 10:
        PMGRPCDLOG.info("Signal handler called with USR1 signal: %s" % (signum))
        PMGRPCDLOG.info("These are the missing gpb libs: %s" % (MISSGPBLIB))
    if signum == 12:
        PMGRPCDLOG.info("Signal handler called with USR2 signal: %s" % (signum))
        PMGRPCDLOG.info("TODO: %s" % ("todo"))



#
#   pmacct (Promiscuous mode IP Accounting package)
#   pmacct is Copyright (C) 2003-2020 by Paolo Lucente
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
#   pmgrpcd and its components are Copyright (C) 2018-2020 by:
#
#   Matthias Arnold <matthias.arnold@swisscom.com>
#   Raphaël P. Barazzutti <raphael@barazzutti.net>
#   Juan Camilo Cardona <jccardona82@gmail.com>
#   Thomas Graf <thomas.graf@swisscom.com>
#   Paolo Lucente <paolo@pmacct.net>
#
import os
import time
from lib_pmgrpcd import PMGRPCDLOG
import lib_pmgrpcd
import sys
import ujson as json
from abc import ABC, abstractmethod

jsonmap = {}
avscmap = {}


example_dict = {}


class Exporter(ABC):
    @abstractmethod
    def process_metric(self, metric):
        pass


EXPORTERS = {}


def export_metrics(datajsonstring):
    for exporter in EXPORTERS:
        try:
            EXPORTERS[exporter].process_metric(datajsonstring)
        except Exception as e:
            PMGRPCDLOG.debug("Error processing packet on exporter %s. Error was %s", exporter, e)
            raise


def examples(dictTelemetryData_mod, jsonTelemetryData):
    global example_dict
    if dictTelemetryData_mod["collector"]["grpc"]["grpcPeer"]:
        grpcPeer = dictTelemetryData_mod["collector"]["grpc"]["grpcPeer"]
        if dictTelemetryData_mod["collector"]["grpc"]["ne_vendor"]:
            ne_vendor = dictTelemetryData_mod["collector"]["grpc"]["ne_vendor"]
            if dictTelemetryData_mod["collector"]["data"]["encoding_path"]:
                encoding_path = dictTelemetryData_mod["collector"]["data"][
                    "encoding_path"
                ]

                PMGRPCDLOG.debug(
                    "IN EXAMPLES: grpcPeer=%s ne_vendor=%s encoding_path=%s"
                    % (grpcPeer, ne_vendor, encoding_path)
                )

    try:
        if not os.path.exists(lib_pmgrpcd.OPTIONS.examplepath):
            os.makedirs(lib_pmgrpcd.OPTIONS.examplepath)
    except OSError:
        pass
    if grpcPeer not in example_dict:
        example_dict.update({grpcPeer: []})

    if encoding_path not in example_dict[grpcPeer]:
        example_dict[grpcPeer].append(encoding_path)
        encoding_path_mod = encoding_path.replace(":", "_").replace("/", "-")

        exafilename = grpcPeer + "_" + ne_vendor + "_" + encoding_path_mod + ".json"
        exapathfile = os.path.join(lib_pmgrpcd.OPTIONS.examplepath, exafilename)

        with open(exapathfile, "w") as exapathfile:
            # exapathfile.write("PROTOPATH[" + telemetry_node + "]: " + protopath + "\n")
            exapathfile.write(jsonTelemetryData)
            exapathfile.write("\n")


def FinalizeTelemetryData(dictTelemetryData):

    # Adding epoch in millisecond to identify this singel metric on the way to the storage
    epochmillis = int(round(time.time() * 1000))
    dictTelemetryData["collector"]["data"].update({"collection_timestamp": epochmillis})

    dictTelemetryData_mod = dictTelemetryData.copy()

    # Going over the mitigation library, if needed.
    # TODO: Simplify the next part
    if lib_pmgrpcd.OPTIONS.mitigation:
        from mitigation import mod_all_json_data
        try:
            dictTelemetryData_mod = mod_all_json_data(dictTelemetryData_mod)
            jsonTelemetryData = json.dumps(
                dictTelemetryData_mod, indent=2, sort_keys=True
            )
        except Exception as e:
            PMGRPCDLOG.info("ERROR: mod_all_json_data raised a error:\n%s")
            PMGRPCDLOG.info("ERROR: %s" % (e))
            dictTelemetryData_mod = dictTelemetryData
            jsonTelemetryData = json.dumps(dictTelemetryData, indent=2, sort_keys=True)
    else:
        dictTelemetryData_mod = dictTelemetryData
        jsonTelemetryData = json.dumps(dictTelemetryData, indent=2, sort_keys=True)

    PMGRPCDLOG.debug("After mitigation: %s" % (jsonTelemetryData))

    if lib_pmgrpcd.OPTIONS.examplepath and lib_pmgrpcd.OPTIONS.example:
        examples(dictTelemetryData_mod, jsonTelemetryData)

    if lib_pmgrpcd.OPTIONS.jsondatadumpfile:
        PMGRPCDLOG.debug("Write jsondatadumpfile: %s" % (lib_pmgrpcd.OPTIONS.jsondatadumpfile))
        with open(lib_pmgrpcd.OPTIONS.jsondatadumpfile, "a") as jsondatadumpfile:
            jsondatadumpfile.write(jsonTelemetryData)
            jsondatadumpfile.write("\n")

    # Filter only config.
    export = True
    if lib_pmgrpcd.OPTIONS.onlyopenconfig:
        PMGRPCDLOG.debug(
            "only openconfig filter matched because of options.onlyopenconfig: %s"
            % lib_pmgrpcd.OPTIONS.onlyopenconfig
        )
        export = False
        if "encoding_path" in dictTelemetryData_mod["collector"]["data"]:
            if (
                "openconfig"
                in dictTelemetryData_mod["collector"]["data"]["encoding_path"]
            ):
                export = True

    if export:
        export_metrics(jsonTelemetryData)

    return jsonTelemetryData



#
#   pmacct (Promiscuous mode IP Accounting package)
#   pmacct is Copyright (C) 2003-2020 by Paolo Lucente
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
#   pmgrpcd and its components are Copyright (C) 2018-2020 by:
#
#   Matthias Arnold <matthias.arnold@swisscom.com>
#   Raphaël P. Barazzutti <raphael@barazzutti.net>
#   Juan Camilo Cardona <jccardona82@gmail.com>
#   Thomas Graf <thomas.graf@swisscom.com>
#   Paolo Lucente <paolo@pmacct.net>
#
import huawei_grpc_dialout_pb2_grpc
from lib_pmgrpcd import PMGRPCDLOG
import ujson as json
import lib_pmgrpcd
from google.protobuf.json_format import MessageToDict
import time
from datetime import datetime
from export_pmgrpcd import FinalizeTelemetryData
import base64

# TODO: Maybe move this to its own part, who knows
import huawei_ifm_pb2
import huawei_devm_pb2
import openconfig_interfaces_pb2

if lib_pmgrpcd.OPTIONS.huawei and (not lib_pmgrpcd.OPTIONS.cenctype == 'gpbkv'):
    import huawei_telemetry_pb2


class gRPCDataserviceServicer(huawei_grpc_dialout_pb2_grpc.gRPCDataserviceServicer):
    def __init__(self):
        PMGRPCDLOG.info("Huawei: Initializing gRPCDataserviceServicer()")

    def dataPublish(self, message, context):
        grpcPeer = {}
        grpcPeerStr = context.peer()
        (
            grpcPeer["telemetry_proto"],
            grpcPeer["telemetry_node"],
            grpcPeer["telemetry_node_port"],
        ) = grpcPeerStr.split(":")
        grpcPeer["ne_vendor"] = "Huawei"
        PMGRPCDLOG.debug("Huawei MdtDialout Message: %s" % grpcPeer["telemetry_node"])

        metadata = dict(context.invocation_metadata())
        grpcPeer["user-agent"] = metadata["user-agent"]
        # Example of grpcPeerStr -> 'ipv4:10.215.133.23:57775'
        grpcPeer["grpc_processing"] = "huawei_grpc_dialout_pb2_grpc"
        grpcPeer["grpc_ulayer"] = "GPB Telemetry"
        jsonTelemetryNode = json.dumps(grpcPeer, indent=2, sort_keys=True)
        PMGRPCDLOG.debug("Huawei RAW Message: %s" % jsonTelemetryNode)

        for new_msg in message:
            PMGRPCDLOG.debug("Huawei new_msg iteration message")
            if lib_pmgrpcd.OPTIONS.ip:
                if grpcPeer["telemetry_node"] != lib_pmgrpcd.OPTIONS.ip:
                    continue
                PMGRPCDLOG.debug(
                    "Huawei: ip filter matched with ip %s"
                    % (lib_pmgrpcd.OPTIONS.ip)
                )
            try:
                huawei_processing(grpcPeer, new_msg)
            except Exception as e:
                PMGRPCDLOG.debug("Error processing Huawei packet, error is %s", e)
                continue
        return
        yield


def huawei_processing(grpcPeer, new_msg):
    PMGRPCDLOG.debug("Huawei: Received GRPC-Data")

    try:
        telemetry_msg = huawei_telemetry_pb2.Telemetry()
        telemetry_msg.ParseFromString(new_msg.data)
    except Exception as e:
        PMGRPCDLOG.error(
            "instancing or parsing data failed with huawei_telemetry_pb2.Telemetry"
        )
        PMGRPCDLOG.error("ERROR: %s" % (e))
        raise

    try:
        telemetry_msg_dict = MessageToDict(
            telemetry_msg,
            including_default_value_fields=True,
            preserving_proto_field_name=True,
            use_integers_for_enums=True,
        )
    except Exception as e:
        PMGRPCDLOG.error(
            "instancing or parsing data failed with huawei_telemetry_pb2.Telemetry"
        )
        raise


    PMGRPCDLOG.debug("Huawei: Received GPB-Data as JSON")
    # TODO: Do we really need this? it can be expensive 
    PMGRPCDLOG.debug(json.dumps(telemetry_msg_dict, indent=2, sort_keys=True))

    message_header_dict = telemetry_msg_dict.copy()

    if "data_gpb" in message_header_dict:
        del message_header_dict["data_gpb"]

    (proto, path) = message_header_dict["sensor_path"].split(":")
    (node_id_str) = message_header_dict["node_id_str"]
    (node_ip) = grpcPeer["telemetry_node"]
    (ne_vendor) = grpcPeer["ne_vendor"]

    # Get the maching L3-Methode
    msg = select_gbp_methode(proto)
    if msg:
        elem = len(telemetry_msg.data_gpb.row)
        epochmillis = int(round(time.time() * 1000))
        PMGRPCDLOG.info(
            "EPOCH=%-10s NIP=%-15s NID=%-20s VEN=%-7s PT=%-22s ET=%-12s ELEM:%s"
            % (epochmillis, node_ip, node_id_str, ne_vendor, proto, "GPB", elem)
        )

        # L2:
        for new_row in telemetry_msg.data_gpb.row:
            # PMGRPCDLOG.info("NEW_ROW: %s" % (new_row))
            new_row_header_dict = MessageToDict(
                new_row,
                including_default_value_fields=True,
                preserving_proto_field_name=True,
                use_integers_for_enums=True,
            )

            if "content" in new_row_header_dict:
                del new_row_header_dict["content"]

            # L3:
            msg.ParseFromString(new_row.content)
            content = MessageToDict(
                msg,
                including_default_value_fields=True,
                preserving_proto_field_name=True,
                use_integers_for_enums=True,
            )

            message_dict = {}
            message_dict.update(
                {
                    "collector": {
                        "grpc": {
                            "grpcPeer": grpcPeer["telemetry_node"],
                            "ne_vendor": grpcPeer["ne_vendor"],
                        }
                    }
                }
            )
            message_dict["collector"].update({"data": message_header_dict.copy()})
            message_dict["collector"]["data"].update(new_row_header_dict)
            message_dict.update(content)

            # dump the raw data
            if lib_pmgrpcd.OPTIONS.rawdatadumpfile:
                PMGRPCDLOG.debug("Write rawdatadumpfile: %s" % (lib_pmgrpcd.OPTIONS.rawdatadumpfile))
                with open(lib_pmgrpcd.OPTIONS.rawdatadumpfile, "a") as rawdatadumpfile:
                    rawdatadumpfile.write(json.dumps(message_dict, indent=2, sort_keys=True))
                    rawdatadumpfile.write("\n")

            allkeys = parse_dict(content, ret="", level=0)
            PMGRPCDLOG.debug("Huawei: %s: %s" % (proto, allkeys))

            try:
                returned = FinalizeTelemetryData(message_dict)
            except Exception as e:
                PMGRPCDLOG.error("Error finalizing  message: %s", e)

# TODO, probably better to have this in the object


MAP_DICT = None
def get_gpbmapfile():
    global MAP_DICT
    if MAP_DICT is None:
        with open(lib_pmgrpcd.OPTIONS.gpbmapfile, "r") as file:
            MAP_DICT = {}
            for line in file:
                (k, v) = line.split("=")
                # a.e. "huawei-ifm" = 'huawei_ifm_pb2.Ifm()'
                MAP_DICT.update({k.lstrip().rstrip(): v.lstrip().rstrip()})
        PMGRPCDLOG.debug("MAP_DICT: %s", MAP_DICT)
    return MAP_DICT


def select_gbp_methode(proto):
    try:
        map_dict = get_gpbmapfile()
    except:
        PMGRPCDLOG.error(
            "Error getting the map dict"
        )
        raise

    if proto in map_dict:
        PMGRPCDLOG.debug(
            "I FOUND THE GPB (%s) FOR PROTO (%s)" % (proto, map_dict[proto])
        )
        # TODO: I am pretty sure we can do something better than this.
        msg = eval(map_dict[proto])
        return msg
    else:
        PMGRPCDLOG.debug("MISSING GPB Methode for PROTO: %s", proto)
        lib_pmgrpcd.MISSGPBLIB.update({proto: str(datetime.now())})
        return False

def parse_dict(init, ret, level):
    level += 1
    if isinstance(init, dict):
        for key, val in init.items():
            if isinstance(val, dict):
                if level == 1:
                    if key != "grpc":
                        ret = ret + "|" + key
                else:
                    ret = ret + "->" + key
                ret = parse_dict(val, ret, level)
            if isinstance(val, list):
                for liit in val:
                    ind = val.index(liit)
                    if isinstance(liit, dict):
                        if level == 1:
                            if liit != "grpc":
                                ret = ret + "|" + key + "->[" + str(ind) + "]"
                        else:
                            ret = ret + "->" + key + "->[" + str(ind) + "]"
                        ret = parse_dict(liit, ret, level)
    return ret



#
#   pmacct (Promiscuous mode IP Accounting package)
#   pmacct is Copyright (C) 2003-2020 by Paolo Lucente
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
#   pmgrpcd and its components are Copyright (C) 2018-2020 by:
#
#   Matthias Arnold <matthias.arnold@swisscom.com>
#   Raphaël P. Barazzutti <raphael@barazzutti.net>
#   Juan Camilo Cardona <jccardona82@gmail.com>
#   Thomas Graf <thomas.graf@swisscom.com>
#   Paolo Lucente <paolo@pmacct.net>
#
from __future__ import print_function
from zmq import ZMQError
import zmq
from optparse import OptionParser
import sys

def eprint(*args, **kwargs):
    print(*args, file=sys.stderr, **kwargs)



DEFAULT_PORT = "tcp://127.0.0.1:50000"

parser = OptionParser()
parser.add_option(
    "-p",
    "--port",
    default=str(DEFAULT_PORT),
    dest="port",
    help="Port to setup the server",
)
(options, _) = parser.parse_args()

zmqContext = zmq.Context()
zmqSock = zmqContext.socket(zmq.PULL)
zmqSock.connect(options.port)
eprint("zmq ready")

while True:
    work = zmqSock.recv_json().strip()
    if work:
        print(work)
